<?php
/**
 * Theme About Page
 *
 * @package meditate
 * @since 1.0
 */

function meditate_theme_page_admin_style( $hook ) {
	if ( 'appearance_page_meditate-theme' === $hook ) {
		// Register theme stylesheet.
		$theme_version = wp_get_theme()->get( 'Version' );

		$version_string = is_string( $theme_version ) ? $theme_version : false;
		wp_enqueue_style(
			'meditate-theme-admin-style',
			get_theme_file_uri( 'assets/css/about-admin.css' ),
			array(),
			$version_string
		);
	}
}
add_action( 'admin_enqueue_scripts', 'meditate_theme_page_admin_style' );

/**
 * Add theme page
 */
function meditate_menu() {
	add_theme_page( esc_html__( 'Meditate', 'meditate' ), esc_html__( 'Meditate', 'meditate' ), 'edit_theme_options', 'meditate-theme', 'meditate_theme_page_display' );
}
add_action( 'admin_menu', 'meditate_menu' );

/**
 * Display About page
 */
function meditate_theme_page_display() {
	$theme = wp_get_theme();
	
	if ( is_child_theme() ) {
		$theme = wp_get_theme()->parent();
	}
	?>
	
	<div id="welcome-panel" class="welcome-panel">
		<div class="welcome-panel-content">
			<div class="welcome-panel-header">
				<h2><?php echo esc_html( $theme->Name ); ?></h2>
				<p><?php esc_html_e( 'Free Full Site Editing WordPress Theme', 'meditate' ); ?></p>
				<div class="logo-panel">
					<a href="<?php echo esc_url('https://alexathemes.net/','meditate'); ?>"><img src="<?php echo esc_url( get_template_directory_uri().'/assets/img/logo.png' ); ?>"></a>
				</div>
			</div>
			
			<div class="welcome-panel-column-container">
				<div class="container-wrap">
					<div class="welcome-panel-column two-columns">
						<!-- <div class="welcome-panel-icon-pages"></div> -->
						<div class="welcome-panel-column-content">
							<h3><?php esc_html_e( 'Getting Started with Meditate!', 'meditate' ); ?></h3>
							<p><?php esc_html_e( 'Awesome! Meditate has been installed and activated successfully. Now, you can start building your dream website with a wide range of highly-customizable block patterns, templates, and template parts available in this astounding theme.', 'meditate' ); ?></p>
						</div>
					</div>
					
					<div class="welcome-panel-column two-columns">
						<div class="welcome-panel-column-content">
							<h3><?php esc_html_e( 'More Features with Meditate Pro Theme', 'meditate' ); ?></h3>
							<p><?php esc_html_e( 'To get more features and unique home page sections, we recommend you activate the Meditate Pro. With the pro theme installed, get more options like google fonts, colors, sliders, page template, shortcodes and more.', 'meditate' ); ?></p>
							<a target="_blank" class="button green button-primary button-hero green" href="https://alexathemes.net/themes/meditate-wordpress-theme/"><?php esc_html_e( 'Buy Meditate Pro', 'meditate' ); ?></a>
						</div>
					</div>
					
				</div>
				<div class="sidebar">
					<div class="welcome-panel-column important-links">
					<!-- <div class="welcome-panel-icon-pages"></div> -->
					<div class="welcome-panel-column-content">
						<h3><?php esc_html_e( 'Important Links', 'meditate' ); ?></h3>
						<a target="_blank" href="<?php echo esc_url( 'https://alexathemes.net/themes/meditate-wordpress-theme/' ); ?>"><?php esc_html_e( 'Theme Info', 'meditate' ); ?></a>
						<a target="_blank" href="http://live-demo.online/meditate/"><?php esc_html_e( 'View Demo', 'meditate' ); ?></a>
						<a target="_blank" href="<?php echo esc_url( 'https://alexathemes.net/forums/' ); ?>"><?php esc_html_e( 'Support', 'meditate' ); ?></a>
					</div>
				</div>
				
				<div class="welcome-panel-column review">
					<!-- <div class="welcome-panel-icon-pages"></div> -->
					<div class="welcome-panel-column-content">
						<h3><?php esc_html_e( 'Leave us a review', 'meditate' ); ?></h3>
						<p><?php esc_html_e( 'Loved Meditate? Feel free to leave your feedback. Your opinion helps us reach more audiences!', 'meditate' ); ?></p>
						<a href="https://wordpress.org/support/theme/meditate/reviews/" class="button button-primary button-hero" style="text-decoration: none;" target="_blank"><?php esc_html_e( 'Review', 'meditate' ); ?></a>
					</div>
				</div>
				</div>
			</div>
		</div>
	</div>
	<?php
}
